@@ -1,4 +1,4 @@
-# $Id: wetter.py 1156 2014-12-03 19:44:45Z mwall $
+# $Id: wetter.py 1343 2015-07-24 23:49:19Z mwall $
 # Copyright 2013 Matthew Wall
 """
 Upload data to wetter.com
@@ -11,6 +11,7 @@ Upload data to wetter.com
 """
 
 import Queue
+import re
 import sys
 import syslog
 import time
@@ -22,7 +23,7 @@ import weewx.restx
 import weewx.units
 from weeutil.weeutil import to_bool, accumulateLeaves
 
-VERSION = "0.2"
+VERSION = "0.3"
 
 if weewx.__version__ < "3":
     raise weewx.UnsupportedFeature("weewx 3 is required, found %s" %
@@ -105,10 +106,13 @@ class WetterThread(weewx.restx.RESTThread):
     def process_record(self, record, dbm):
         r = self.get_record(record, dbm)
         data = self.get_data(r)
+        url = urllib.urlencode(data)
+        if weewx.debug >= 2:
+            logdbg('url: %s' % re.sub(r"passwort=[^\&]*", "passwort=XXX", url))
         if self.skip_upload:
             loginf("skipping upload")
             return
-        req = urllib2.Request(self.server_url, urllib.urlencode(data))
+        req = urllib2.Request(self.server_url, url)
         req.get_method = lambda: 'POST'
         req.add_header("User-Agent", "weewx/%s" % weewx.__version__)
         self.post_with_retries(req)
@@ -137,5 +141,4 @@ class WetterThread(weewx.restx.RESTThread):
                 v = record[rkey] * self._DATA_MAP[key][2]
                 values[key] = self._DATA_MAP[key][1] % v
 
-        logdbg('data: %s' % values)
         return values
